ardt.datasets.cuads.CuadsDataset
================================

.. currentmodule:: ardt.datasets.cuads

.. autoclass:: CuadsDataset

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~CuadsDataset.__init__
      ~CuadsDataset.get_media_name_by_movie_id
      ~CuadsDataset.get_signal_metadata
      ~CuadsDataset.get_trial_splits
      ~CuadsDataset.get_working_dir
      ~CuadsDataset.get_working_path
      ~CuadsDataset.load_trials
      ~CuadsDataset.preload
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~CuadsDataset.expected_media_responses
      ~CuadsDataset.media_file_offset
      ~CuadsDataset.media_ids
      ~CuadsDataset.participant_ids
      ~CuadsDataset.participant_offset
      ~CuadsDataset.signal_preprocessors
      ~CuadsDataset.signals
      ~CuadsDataset.trials
   
   